==> hexo-highlight-mark-1.1.1.tgz: package/lib/filter.js <==
'use strict';

const alias = require('../highlight_alias.json');
const highlight = require('./highlight');

const rBacktick = /^((?:[^\S\r\n]*>){0,3}[^\r\n]*)(`{3,}|~{3,})[\r\n]*((?:.*?[^`\s])?)[^\S\r\n]*\n((?:[\s\S]*?\n)?)(?:(?:[^\S\r\n]*>){0,3}[^\S\r\n]*)\2[^\S\r\n]?(\n+|$)/gm;
const rLangCaption = /^(\w*)\s*([^\r\n]*)/;
const rCaptionMark = /([^{][^\s]+)?\s*(?:{([^\s]+)})?/;

const escapeSwigTag = str => str.replace(/{/g, '&#123;').replace(/}/g, '&#125;');

const getHighlightDirectiveRegex = (languages = ['js', 'jsBlock', 'jsx', 'python', 'html']) => {
    // supported types of comments
    const comments = {
        js: {
            start: '\\/\\/',
            end: ''
        },
        jsBlock: {
            start: '\\/\\*',
            end: '\\*\\/'
        },
        jsx: {
            start: '\\{\\s*\\/\\*',
            end: '\\*\\/\\s*\\}'
        },
        python: {
            start: '#',
            end: ''
        },
        html: {
            start: '<!--',
            end: '-->'
        }
    }; // supported directives

    const directives = ['highlight-next-line', 'highlight-start', 'highlight-end'].join('|'); // to be more reliable, the opening and closing comment must match

    const commentPattern = languages.map(lang => `(?:${comments[lang].start}\\s*(${directives})\\s*${comments[lang].end})`).join('|'); // white space is allowed, but otherwise it should be on it's own line

    return new RegExp(`^\\s*(?:${commentPattern})\\s*$`);
}

const highlightDirectiveRegex = lang => {
    switch (lang) {
        case 'js':
        case 'javascript':
        case 'ts':
        case 'typescript':
            return getHighlightDirectiveRegex(['js', 'jsBlock']);

        case 'jsx':
        case 'tsx':
            return getHighlightDirectiveRegex(['js', 'jsBlock', 'jsx']);

        case 'html':
            return getHighlightDirectiveRegex(['js', 'jsBlock', 'html']);

        case 'python':
        case 'py':
            return getHighlightDirectiveRegex(['python']);

        default:
            // all comment types
            return getHighlightDirectiveRegex();
    }
};

module.exports = function (data) {

    const dataContent = data.content;

    const hljsCfg = this.config.highlight || {};

    if ((!dataContent.includes('```') && !dataContent.includes('~~~')) || (!hljsCfg.enable)) return;


    data.content = dataContent.replace(rBacktick, ($0, start, $2, _args, _content, end) => {
        let content = _content.replace(/\n$/, '');
        const args = _args;

        // neither highlight is enabled, return escaped content directly.
        if (!hljsCfg.enable) return escapeSwigTag($0);

        // Extract language and caption of code blocks
        let lang;
        let code_options = {
            title: '',
            mark: []
        }

        if (args) {
            const match = rLangCaption.exec(args);

            if (match) {
                if (match[1]) {
                    lang = alias.aliases[match[1]] ? alias.aliases[match[1]] : match[1];
                }
                parse_args(match[2], code_options);
            }
        }

        const info = get_highlight_comment(content, highlightDirectiveRegex(lang));
        content = info.code
        code_options.mark = code_options.mark.concat(info.marked)
        code_options.mark = code_options.mark.filter((item, index, arr) => arr.indexOf(item, 0) === index)

        // PR #3765
        if (start.includes('>')) {
            // heading of last line is already removed by the top RegExp "rBacktick"
            const depth = start.split('>').length - 1;
            const regexp = new RegExp(`^([^\\S\\r\\n]*>){0,${depth}}([^\\S\\r\\n]|$)`, 'mg');
            content = content.replace(regexp, '');
        }


        const options = {
            hljs: hljsCfg.hljs,
            autoDetect: hljsCfg.auto_detect,
            tab: hljsCfg.tab_replace,
            lang,
            caption: code_options.title,
            mark: code_options.mark
        };

        content = highlight(content, options);

        return start
            + '<hexoPostRenderCodeBlock>'
            + escapeSwigTag(content)
            + '</hexoPostRenderCodeBlock>'
            + end;
    });

};

function parse_args(str, options) {
    const match = rCaptionMark.exec(str);
    options.title = match[1].replace('title:', '') || '';
    options.mark = parse_mark(match[2]);
    return options
}

function parse_mark(str) {
    let res_list = [];
    let lines = str.split(',');

    lines.forEach(e => {
        if (e.includes('-')) {
            const start_end = e.split('-');
            for (let i = 0; i <= start_end[1] - start_end[0]; i++) {
                res_list.push(Number(start_end[0]) + i)
            }
        } else {
            res_list.push(Number(e));
        }
    });
    return res_list
}

function get_highlight_comment(content, reg) {
    const lines = content.replace(/\n$/, '').split('\n');
    let range = [];
    let blockStart;

    for (let index = 0; index < lines.length;) {
        const lineNumber = index + 1;
        const line = lines[index];
        const match = line.match(reg);

        if (match !== null) {
            const directives = match.slice(1).reduce((final, item) => final || item, undefined);

            switch (directives) {
                case 'highlight-next-line':
                    range.push(`${lineNumber}`);
                    break;

                case 'highlight-start':
                    blockStart = lineNumber;
                    break;

                case 'highlight-end':
                    range.push(`${blockStart}-${lineNumber - 1}`);
                    break;

                default:
                    break;
            }

            lines.splice(index, 1);
        } else {
            index += 1;
        }
    }
    const marked = parse_mark(range.join(','));
    const code = lines.join('\n');

    const info = { marked: marked, code: code }

    return info

}

==> hexo-highlight-mark-1.1.2.tgz: package/lib/filter.js <==
'use strict';

const alias = require('../highlight_alias.json');
const highlight = require('./highlight');

const rBacktick = /^((?:[^\S\r\n]*>){0,3}[^\r\n]*)(`{3,}|~{3,})[\r\n]*((?:.*?[^`\s])?)[^\S\r\n]*\n((?:[\s\S]*?\n)?)(?:(?:[^\S\r\n]*>){0,3}[^\S\r\n]*)\2[^\S\r\n]?(\n+|$)/gm;
const rLangCaption = /^(\w*)\s*([^\r\n]*)/;
const rCaptionMark = /([^{][^\s]+)?\s*(?:{([^\s]+)})?/;

const escapeSwigTag = str => str.replace(/{/g, '&#123;').replace(/}/g, '&#125;');

const getHighlightDirectiveRegex = (languages = ['js', 'jsBlock', 'jsx', 'python', 'html']) => {
    // supported types of comments
    const comments = {
        js: {
            start: '\\/\\/',
            end: ''
        },
        jsBlock: {
            start: '\\/\\*',
            end: '\\*\\/'
        },
        jsx: {
            start: '\\{\\s*\\/\\*',
            end: '\\*\\/\\s*\\}'
        },
        python: {
            start: '#',
            end: ''
        },
        html: {
            start: '<!--',
            end: '-->'
        }
    }; // supported directives

    const directives = ['highlight-next-line', 'highlight-start', 'highlight-end'].join('|'); // to be more reliable, the opening and closing comment must match

    const commentPattern = languages.map(lang => `(?:${comments[lang].start}\\s*(${directives})\\s*${comments[lang].end})`).join('|'); // white space is allowed, but otherwise it should be on it's own line

    return new RegExp(`^\\s*(?:${commentPattern})\\s*$`);
}

const highlightDirectiveRegex = lang => {
    switch (lang) {
        case 'js':
        case 'javascript':
        case 'ts':
        case 'typescript':
            return getHighlightDirectiveRegex(['js', 'jsBlock']);

        case 'jsx':
        case 'tsx':
            return getHighlightDirectiveRegex(['js', 'jsBlock', 'jsx']);

        case 'html':
            return getHighlightDirectiveRegex(['js', 'jsBlock', 'html']);

        case 'python':
        case 'py':
            return getHighlightDirectiveRegex(['python']);

        default:
            // all comment types
            return getHighlightDirectiveRegex();
    }
};

module.exports = function (data) {

    const dataContent = data.content;

    const hljsCfg = this.config.highlight || {};

    if ((!dataContent.includes('```') && !dataContent.includes('~~~')) || (!hljsCfg.enable)) return;


    data.content = dataContent.replace(rBacktick, ($0, start, $2, _args, _content, end) => {
        let content = _content.replace(/\n$/, '');
        const args = _args;

        // neither highlight is enabled, return escaped content directly.
        if (!hljsCfg.enable) return escapeSwigTag($0);

        // Extract language and caption of code blocks
        let lang;
        let code_options = {
            title: '',
            mark: []
        }

        if (args) {
            const match = rLangCaption.exec(args);

            if (match) {
                if (match[1]) {
                    lang = alias.aliases[match[1]] ? alias.aliases[match[1]] : match[1];
                }
                parse_args(match[2], code_options);
            }
        }

        const info = get_highlight_comment(content, highlightDirectiveRegex(lang));
        content = info.code
        code_options.mark = code_options.mark.concat(info.marked)
        code_options.mark = code_options.mark.filter((item, index, arr) => arr.indexOf(item, 0) === index)

        // PR #3765
        if (start.includes('>')) {
            // heading of last line is already removed by the top RegExp "rBacktick"
            const depth = start.split('>').length - 1;
            const regexp = new RegExp(`^([^\\S\\r\\n]*>){0,${depth}}([^\\S\\r\\n]|$)`, 'mg');
            content = content.replace(regexp, '');
        }


        const options = {
            hljs: hljsCfg.hljs,
            autoDetect: hljsCfg.auto_detect,
            tab: hljsCfg.tab_replace,
            lang,
            caption: code_options.title,
            mark: code_options.mark
        };

        content = highlight(content, options);

        return start
            + '<hexoPostRenderCodeBlock>'
            + escapeSwigTag(content)
            + '</hexoPostRenderCodeBlock>'
            + end;
    });

};

function parse_args(str, options) {
    const match = rCaptionMark.exec(str);
    // options.title = match[1].replace('title:', '') || '';
    options.title = match[1] ? match[1].replace('title:', '') : '';
    options.mark = match[2] ? parse_mark(match[2]) : [];
    return options
}

function parse_mark(str) {
    let res_list = [];
    let lines = str.split(',');

    lines.forEach(e => {
        if (e.includes('-')) {
            const start_end = e.split('-');
            for (let i = 0; i <= start_end[1] - start_end[0]; i++) {
                res_list.push(Number(start_end[0]) + i)
            }
        } else {
            res_list.push(Number(e));
        }
    });
    return res_list
}

function get_highlight_comment(content, reg) {
    const lines = content.replace(/\n$/, '').split('\n');
    let range = [];
    let blockStart;

    for (let index = 0; index < lines.length;) {
        const lineNumber = index + 1;
        const line = lines[index];
        const match = line.match(reg);

        if (match !== null) {
            const directives = match.slice(1).reduce((final, item) => final || item, undefined);

            switch (directives) {
                case 'highlight-next-line':
                    range.push(`${lineNumber}`);
                    break;

                case 'highlight-start':
                    blockStart = lineNumber;
                    break;

                case 'highlight-end':
                    range.push(`${blockStart}-${lineNumber - 1}`);
                    break;

                default:
                    break;
            }

            lines.splice(index, 1);
        } else {
            index += 1;
        }
    }
    const marked = parse_mark(range.join(','));
    const code = lines.join('\n');

    const info = { marked: marked, code: code }

    return info

}
